@@ -2,19 +2,25 @@ package org.gcube.portlets.user.td.gwtservice.shared.codelisthelper;
 
 import java.io.Serializable;
 
-import org.gcube.portlets.user.td.gwtservice.shared.resource.ResourceTD;
 import org.gcube.portlets.user.td.gwtservice.shared.source.Source;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.resources.ResourceTDDescriptor;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 
+/**
+ * 
+ * @author giancarlo
+ * email: <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
+ *
+ */
 public class CodelistMappingSession implements Serializable {
 
 	private static final long serialVersionUID = 2381185326076784908L;
 
 	protected TRId trId;
 	protected Source source;
-	protected ResourceTD resourceTD;
+	protected ResourceTDDescriptor resourceTDDescriptor;
 	protected String url;
 	protected String localFileName;
 	protected String itemId;
@@ -61,12 +67,12 @@ public class CodelistMappingSession implements Serializable {
 		this.url = url;
 	}
 
-	public ResourceTD getResourceTD() {
-		return resourceTD;
+	public ResourceTDDescriptor getResourceTDDescriptor() {
+		return resourceTDDescriptor;
 	}
 
-	public void setResourceTD(ResourceTD resourceTD) {
-		this.resourceTD = resourceTD;
+	public void setResourceTDDescriptor(ResourceTDDescriptor resourceTDDescriptor) {
+		this.resourceTDDescriptor = resourceTDDescriptor;
 	}
 
 	public TabResource getConnectedTR() {
@@ -88,12 +94,14 @@ public class CodelistMappingSession implements Serializable {
 	@Override
 	public String toString() {
 		return "CodelistMappingSession [trId=" + trId + ", source=" + source
-				+ ", resourceTD=" + resourceTD + ", url=" + url
-				+ ", localFileName=" + localFileName + ", itemId=" + itemId
-				+ ", connectedTR=" + connectedTR + ", connectedColumn="
-				+ connectedColumn + "]";
+				+ ", resourceTDDescriptor=" + resourceTDDescriptor + ", url="
+				+ url + ", localFileName=" + localFileName + ", itemId="
+				+ itemId + ", connectedTR=" + connectedTR
+				+ ", connectedColumn=" + connectedColumn + "]";
 	}
 
+
+	
 	
 
 }
